==> v8.3.zip: ru_twords_ru_tw/bible/names/edom.md <==
# Едом, едомляне, Идумея, Сеир, Теман

## Факты:

Едом — это ещё одно имя Исава. Местность, в которой жил Исав, также была известна под названием “Едома”, а позже — “Идумеи”. Едомляне были потомками Исава.

* Регион Едома со временем сместился: сначала он находился на юге Израиля, но потом расширился и стал включать в себя также южную Иудею.
* В новозаветные времена Едом охватывал южную половину провинции Иудея. Греки называли её “Идумеей”.
* Название “Едом” означает “рыжий”. Вероятно, это связано с тем, что новорожденный Исав был покрыт рыжими волосами. Также это может быть связано с красной чечевичной похлебкой, которую Исав выменял на первородство.
* В Ветхом Завете Едом часто упоминается как страна, вражески настроенная против Израиля.
* В книге пророка Авдия говорится о разрушении Едома. Недобрые пророчества о Едоме произносили и другие ветхозаветные пророки.

(Варианты перевода: [Как переводить имена](rc://*/ta/man/translate/translate-names))

(См. также: [противник, враг](../other/adversary.md), [первородство](../kt/birthright.md), [Исав](../names/esau.md), [Авдий](../names/obadiah.md), [пророк, пророчество, пророчествовать, провидец, пророчица](../kt/prophet.md))

## Ссылки на библейский текст:

* [Быт. 25:29-30](rc://*/tn/help/gen/25/29)
* [Быт. 32:3-5](rc://*/tn/help/gen/32/03)
* [Быт. 36:1-3](rc://*/tn/help/gen/36/01)
* [Ис. 11:14-15](rc://*/tn/help/isa/11/14)
* [Нав. 11:16-17](rc://*/tn/help/jos/11/16)
* [Obadiah 1:1-2](rc://*/tn/help/oba/01/01)

## Данные о слове:

* Номера Стронга: H123, H130, H8165, G2401

==> v9.2.zip: ru_twords_ru_tw/bible/names/edom.md <==
# Едом, едомляне, Идумея, Сеир, Теман

## Факты:

Едом — это ещё одно имя Исава. Местность, в которой жил Исав, также была известна под названием “Едома”, а позже — “Идумеи”. Едомляне были потомками Исава.

* Регион Едома со временем сместился: сначала он находился на юге Израиля, но потом расширился и стал включать в себя также южную Иудею.
* В новозаветные времена Едом охватывал южную половину провинции Иудея. Греки называли её “Идумеей”.
* Название “Едом” означает “рыжий”. Вероятно, это связано с тем, что новорожденный Исав был покрыт рыжими волосами. Также это может быть связано с красной чечевичной похлебкой, которую Исав выменял на первородство.
* В Ветхом Завете Едом часто упоминается как страна, вражески настроенная против Израиля.
* В книге пророка Авдия говорится о разрушении Едома. Недобрые пророчества о Едоме произносили и другие ветхозаветные пророки. 

(Варианты перевода: [Как переводить имена](rc://ru/ta/man/translate/translate-names))

(См. также: [противник, враг](../other/adversary.md), [первородство](../kt/birthright.md), [Исав](../names/esau.md), [Авдий](../names/obadiah.md), [пророк, пророчество, пророчествовать, провидец, пророчица](../kt/prophet.md))

## Ссылки на библейский текст:

* [Быт. 25:29-30](rc://ru/tn/help/gen/25/29)
* [Быт. 32:3-5](rc://ru/tn/help/gen/32/03)
* [Быт. 36:1-3](rc://ru/tn/help/gen/36/01)
* [Ис. 11:14-15](rc://ru/tn/help/isa/11/14)
* [Нав. 11:16-17](rc://ru/tn/help/jos/11/16)
* [Obadiah 1:1-2](rc://ru/tn/help/oba/01/01)

## Данные о слове:

* Номера Стронга: H123, H130, H8165, G2401
